//  Часы
//-----------------------------------------------------------------------
// Обязательно подключаем стандартную библиотеку LiquidCrystal
#include <LiquidCrystal.h>

// Определяем сколько кнопок у нас подключено
#define NUM_KEYS 5
// Для каждой кнопки заносим калибровочные значения(выведены экспериментально)
int  adcKeyVal[NUM_KEYS] = {30, 150, 360, 535, 760};

// Заводим переменные для хранения числа миллисекунд с момента наступления разных событий
unsigned long curMillis , lastTick; 
// Заводим переменные, в которых будут храниться секунды, минуты и часы
int Sec, Min, Hour; 

//-----------------------------------------------------------------------
// Инициализируем дисплей, объясняя программе куда подключены линии RS,EN,DB4,DB5,DB6,DB7
LiquidCrystal lcd(A1, A2, A3, 2, 4, 7);

//-----------------------------------------------------------------------
// Эта функция будет выполнена 1 раз в момент запуска программы Arduino
void setup() 
{
  // Инициализируем LCD как обычно -16 символов и 2 строки
  lcd.begin(16, 2);
  // Курсор находится на первой строке (верхней) и первом слева символе  
}

//-----------------------------------------------------------------------
// Эта функция будет выполнена после функции setup и будет бесконечное число раз повторятся после своего окончания.

void loop() {
  // Записываем в переменную cur_millis  число миллисекунд, прошедших с момента запуска программы Arduino 
  curMillis  = millis();
  
  // Если с прошлым полученным значением миллисекунд разница теперешнего более 1 секунды, то значит наступила новая секунда 
  if (curMillis - lastTick >= 1000) {
                                      // Текущее значение прошедших миллисекунд копируется в переменную с прошлым значением
                                      lastTick = curMillis;
                                      // Увеличиваем число секунд на 1
                                      Sec++;
                                      
                                      // Если у нас стало после этого 60 и более секунд- то это следующая минута
                                      if (Sec >= 60) {
                                                      // Добавляем минуту
                                                      Min++;
                                                      // Обнуляем секунды
                                                      Sec = 0; 
                                                     }
                                      // Если у нас стало после этого 60 и более минут- то это следующий час
                                      if (Min >=60) {
                                                      // Добавляем 1 час
                                                      Hour++;
                                                      // Обнуляем минуты
                                                      Min = 0; 
                                                     }
                                      // Если у нас стало после этого 24 и более часов- то это следующий день
                                      if (Hour >=24) {
                                                      // Обнуляем часы
                                                      Hour=0;
                                                      // Обнуляем минуты
                                                      Min = 0; 
                                                     }
                                      // Устанавливаем курсор в левую верхнюю позицию
                                      lcd.setCursor(0,0);
                                      // Выводим надпись
                                      lcd.print("Clock v1.0");
                                      // Устанавливаем курсор на вторую слева позицию на нижнюю строку
                                      lcd.setCursor(1,1);
                                      
                                      // Если часов меньше 10, то перед цифрой добавляем нолик
                                      if (Hour < 10) {lcd.print("0");}
                                      // Выводим число часов
                                      lcd.print(Hour);
                                      // Выводим двоеточие
                                      lcd.print(":");
                                      // Если минут меньше 10, то перед цифрой добавляем нолик
                                      if (Min < 10) {lcd.print("0");}
                                      // Выводим число минут
                                      lcd.print(Min);
                                      // Выводим двоеточие
                                      lcd.print(":");
                                      // Если секунд меньше 10, то перед цифрой добавляем нолик
                                      if (Sec < 10) {lcd.print("0");}
                                      // Выводим число секунд
                                      lcd.print(Sec);
                                      }
                                      
 // Если вызванная функция get_key вернула нам число 1(была нажата кнопка 1)
 if (get_key()==1) {
                    // Увеличиваем часы на 1
                    Hour++;
                    // Пауза перед следующим увеличением в 0,3 секунды
                    delay(300);
                   }
 // Если вызванная функция get_key вернула нам число 2(была нажата кнопка 2)                  
 if (get_key()==2) {
                    // Увеличиваем минуты на 1
                    Min++;
                    // Обнуляем секунды
                    Sec=0;
                    // Пауза перед следующим увеличением в 0,3 секунды
                    delay(300);
                   }
  
 // Функция loop начнет выполняться сначала 
}

//-----------------------------------------------------------------------
// Эта функция будет выполнена только когда ее вызвали из программы
// Функция читает значение с АЦП, куда подключена аналоговая клавиатура
// и сравнивает с калибровочными значениями, определяя номер нажатой кнопки
int get_key()
	{
	  int input = analogRead(A6);
	  int k;
	  for(k = 0; k < NUM_KEYS; k++) 
	    if(input < adcKeyVal[k]) 
	      return k + 1;     
	  return 0;
	}
