// Обязательно подключаем стандартную библиотеку LiquidCrystal
#include <LiquidCrystal.h>
// Подключаем библиотеку датчика DHT
#include "DHT.h"

//-----------------------------------------------------------------------
// Указываем к какому порту подключен датчик 
#define DHTPIN A0     
// Указываем тип датчика
#define DHTTYPE DHT11  

//-----------------------------------------------------------------------
// Создаем программный объект датчика DHT
DHT dht(DHTPIN, DHTTYPE); 
// Создаем программный объект дисплей lcd, объясняя программе куда подключены линии RS,EN,DB4,DB5,DB6,DB7
LiquidCrystal lcd(A1, A2, A3, 2, 4, 7);

//-----------------------------------------------------------------------
// Эта функция будет выполнена 1 раз в момент запуска программы Arduino
void setup() {
  
  // Инициализируем LCD как обычно -16 символов и 2 строки
  lcd.begin(16, 2);
  
  // Специальная функция инициализации датчика DHT
  dht.begin(); 
  
  Serial.begin(9600);
}

//-----------------------------------------------------------------------
// Эта функция будет выполнена после функции setup и будет бесконечное число раз повторятся после своего окончания.
void loop() {
  // Чтение температуры и влажности занимает по 250 миллисекунд!
  int humDht = dht.readHumidity(); // Считываем в переменную humDht значение влажности с датчика DHT
  int tDht = dht.readTemperature(); // Считываем в переменную tDht значение температуры с датчика DHT

  // Очищаем дисплей от всех надписей 
  lcd.clear();
  // Курсор находится на первой строке (верхней) и первом слева символе 

  // Выводим на дисплей текст
    lcd.print("H:"); 
  // Выводим на дисплей значение переменной humDht   
    lcd.print(humDht);
  // Выводим на дисплей текст
    lcd.print("% T:");
  // Выводим на дисплей значение переменной tDht   
    lcd.print(tDht);
  // Выводим на дисплей текст
    lcd.print("*C");
    delay(1000);
    
  // Выводим в окно монитора последовательного интерфейса значения влажности и температуры
  // с датчика с соответствующими заголовками
  Serial.print("Pressure: ");
  Serial.print(humDht);
  Serial.print("  Temperature: ");
  Serial.println(tDht);
    
  // Функция loop начнет выполняться сначала  
 }
