/* Расположение выводов датчика температуры DS18B20

    -----------
  /| DS18D20   |--------------- Vdd
  || (плоская  |--------------- DQ
  \| часть)    |--------------- G
    -----------

*/
// Обязательно подключаем стандартную библиотеку LiquidCrystal
#include <LiquidCrystal.h>
// Подключаем библиотеку датчика DHT
#include "DHT.h"
// Подключаем библиотеку последовательной шины I2C
#include <Wire.h>
// Подключаем библиотеку датчика давления BMP085
#include <Adafruit_BMP085.h>

//-----------------------------------------------------------------------
// Указываем к какому порту подключен датчик DHT
#define DHTPIN A0     
// Указываем тип датчика DHT
#define DHTTYPE DHT11  

//-----------------------------------------------------------------------
// Создаем программный объект датчика DHT
DHT dht(DHTPIN, DHTTYPE); 

// Создаем программный объект дисплей lcd, объясняя программе куда подключены линии RS,EN,DB4,DB5,DB6,DB7
LiquidCrystal lcd(A1, A2, A3, 2, 4, 7);

// Создаем программный объект датчика BMP
Adafruit_BMP085 bmp;

//-----------------------------------------------------------------------
// Эта функция будет выполнена 1 раз в момент запуска программы Arduino
void setup() {
  
  // Инициализируем LCD как обычно -16 символов и 2 строки
  lcd.begin(16, 2);
  
  // Специальная функция инициализации датчика DHT
  dht.begin(); 
  
  // Специальная функция инициализации датчика BMP085
  bmp.begin();
  
  // Специальная функция инициализации последовательной шины I2C 
  Wire.begin();
}

//-----------------------------------------------------------------------
// Эта функция будет выполнена после функции setup и будет бесконечное число раз повторятся после своего окончания.
void loop() {
// Считываем в переменную humDht значение влажности с датчика DHT
  int humDht = dht.readHumidity(); 
// Считываем в переменную tDht значение температуры с датчика DHT
  int tDht = dht.readTemperature();
// Считываем в переменную tBMP значение температуры с датчика BMP
  float tBmp=bmp.readTemperature(); 
// Считываем в переменную pBMP значение атмосферного давления с датчика BMP и одновременно, умножая на 0.0075, переводим его из паскалей в мм рт.ст.  
  int pBmp=bmp.readPressure()*0.0075; 
  
  // Очищаем дисплей от всех надписей 
  lcd.clear();
  // Курсор находится на первой строке (верхней) и первом слева символе 

  // Выводим на дисплей текст
    lcd.print("H:"); 
  // Выводим на дисплей значение переменной humDht   
    lcd.print(humDht);
  // Выводим на дисплей текст
    lcd.print("% T:");
  // Выводим на дисплей значение переменной tDht   
    lcd.print(tDht);
  // Выводим на дисплей текст
    lcd.print("*C");

  // Переведем курсор на первый слева символ (нумерация начинается с 0) и вторую строку (нумерация начинается с 0) 
    lcd.setCursor(0, 1);
  // Выводим на дисплей текст
    lcd.print("T:");
  // Выводим на дисплей значение переменной tBmp с одним знаком после запятой     
    lcd.print(tBmp,1);
  // Выводим на дисплей текст    
    lcd.print(" P:");
  // Выводим на дисплей значение переменной pBmp     
    lcd.print(pBmp);

  // Пауза в 500 миллисекунд=0,5 секунды
    delay(500);
  // Функция loop начнет выполняться сначала  
 }
