/* Расположение выводов датчика температуры DS18B20

    -----------
  /| DS18D20   |--------------- Vdd
  || (плоская  |--------------- DQ
  \| часть)    |--------------- G
    -----------

*/
// Обязательно подключаем стандартную библиотеку LiquidCrystal
#include <LiquidCrystal.h>
// Подключаем библиотеку датчика DHT
#include "DHT.h"
// Подключаем библиотеку последовательной шины I2C
#include <Wire.h>
// Подключаем библиотеку датчика давления BMP085
#include <Adafruit_BMP085.h>
// Подключаем библиотеку шины 1-Wire
#include <OneWire.h>
// Подключаем библиотеку датчика DS18B20
#include <DallasTemperature.h>
// Подключаем библиотеку RTC
#include "RTClib.h"

//-----------------------------------------------------------------------
// Указываем к какому порту подключен датчик DHT
#define DHTPIN A0     
// Указываем тип датчика DHT
#define DHTTYPE DHT11  
// Указываем к какому порту подключен датчик DS18B20
#define ONE_WIRE_BUS 10
// Определяем сколько кнопок у нас подключено
#define NUM_KEYS 5
// Для каждой кнопки заносим калибровочные значения(выведены экспериментально)
int  adcKeyVal[NUM_KEYS] = {30, 150, 360, 535, 760};
//-----------------------------------------------------------------------
// Создаем программный объект датчика DHT
DHT dht(DHTPIN, DHTTYPE); 

// Создаем программный объект дисплей lcd, объясняя программе куда подключены линии RS,EN,DB4,DB5,DB6,DB7
LiquidCrystal lcd(A1, A2, A3, 2, 4, 7);

// Создаем программный объект датчика BMP
Adafruit_BMP085 bmp;

// Создаем программный объект датчика 1-Wire
OneWire oneWire(ONE_WIRE_BUS);

// Создаем программный объект датчика DS18B20 на основе объекта датчика 1-Wire. 
DallasTemperature sensors(&oneWire);

// Создаем программный объект RTC
RTC_DS1307 RTC;

//-----------------------------------------------------------------------
// Эта функция будет выполнена 1 раз в момент запуска программы Arduino
void setup() {
  
  // Инициализируем LCD как обычно -16 символов и 2 строки
  lcd.begin(16, 2);
  
  // Специальная функция инициализации датчика DHT
  dht.begin(); 
  
  // Специальная функция инициализации датчика BMP085
  bmp.begin();

  // Специальная функция инициализации RTC
  RTC.begin();
  
  // Специальная функция инициализации последовательной шины I2C 
  Wire.begin();

  // Если вызванная функция get_key вернула нам число 1(была нажата кнопка 1), записываем в часы текущее время компьютера на момент компиляции программы
  if (get_key()==1) RTC.adjust(DateTime(__DATE__, __TIME__));
  
  // Специальная функция инициализации датчика DS18B20
  sensors.begin();

}

//-----------------------------------------------------------------------
// Эта функция будет выполнена после функции setup и будет бесконечное число раз повторятся после своего окончания.
void loop() {

// Считываем в переменную humDht значение влажности с датчика DHT
  int humDht = dht.readHumidity(); 
// Считываем в переменную tDht значение температуры с датчика DHT
  int tDht = dht.readTemperature();
// Считываем в переменную tBMP значение температуры с датчика BMP
  float tBmp=bmp.readTemperature(); 
// Считываем в переменную pBMP значение атмосферного давления с датчика BMP и одновременно, умножая на 0.0075, переводим его из паскалей в мм рт.ст.  
  int pBmp=bmp.readPressure()*0.0075; 
// Отсылаем датчику DS18B20 команду на измерение температуры
  sensors.requestTemperatures(); 
// Считываем в переменную tDs значение температуры с датчика DS18B20
  float tDs=sensors.getTempCByIndex(0); 
  
// Запускаем механизм чтения времени с RTC
  DateTime now = RTC.now();
// Считываем в переменную year значение текущего года и вычитаем 2000, чтобы получить две последние цифры 
  int Year=now.year()-2000;
// Считываем в переменную month значение  текущего месяца
  int Month=now.month();
// Считываем в переменную day значение  текущего дня
  int Day=now.day();
// Считываем в переменную hour значение  текущего часа
  int Hour=now.hour();
// Считываем в переменную minute значение  текущей минуты
  int Minute=now.minute();
// Считываем в переменную second значение  текущей секунды
  int Second=now.second();
  
  // Очищаем дисплей от всех надписей 
  lcd.clear();
  // Курсор находится на первой строке (верхней) и первом слева символе
  // Выводим на дисплей значение переменной year  
    lcd.print(Day);
  // Выводим на дисплей текст
    lcd.print('/');
  // Выводим на дисплей значение переменной month  
    lcd.print(Month);
  // Выводим на дисплей текст  
    lcd.print('/');
  // Выводим на дисплей значение переменной day   
    lcd.print(Year);
  // Выводим на дисплей текст  
    lcd.print(' ');
  // Выводим на дисплей значение переменной hour   
    lcd.print(Hour);
  // Выводим на дисплей текст  
    lcd.print(':');
  // Если число минут меньше 10, то на экране дорисовываем перед минутами нолик, например 09  
    if (Minute<10) lcd.print('0');
  // Выводим на дисплей значение переменной minute   
    lcd.print(Minute);
  // Выводим на дисплей текст  
    lcd.print(':');
  // Если число секунд меньше 10, то на экране дорисовываем перед секундами нолик, например 00  
    if (Second<10) lcd.print('0');
  // Выводим на дисплей значение переменной second  
    lcd.print(Second);
   
  // Переведем курсор на первый слева символ (нумерация начинается с 0) и вторую строку (нумерация начинается с 0) 
    lcd.setCursor(0, 1);
  // Выводим на дисплей значение переменной humDht   
    lcd.print(humDht);
  // Выводим на дисплей текст
    lcd.print("o");
  // Выводим на дисплей значение переменной tDs с одним знаком после запятой   
    lcd.print(tDs,1);
  // Выводим на дисплей текст
    lcd.print("i");
  // Выводим на дисплей значение переменной tBmp с одним знаком после запятой     
    lcd.print(tBmp,1);
  // Выводим на дисплей текст    
    lcd.print("p");
  // Выводим на дисплей значение переменной pBmp     
    lcd.print(pBmp); 
    
  // Задержка 1000 мс ( 1 сек)  
    delay(1000);
  // Функция loop начнет выполняться сначала     
 }

//-----------------------------------------------------------------------
// Эта функция будет выполнена только когда ее вызвали из программы
// Функция читает значение с АЦП, куда подключена аналоговая клавиатура
// и сравнивает с калибровочными значениями, определяя номер нажатой кнопки
int get_key()
  {
    int input = analogRead(A6);
    int k;
    for(k = 0; k < NUM_KEYS; k++) 
      if(input < adcKeyVal[k]) 
        return k + 1;     
    return 0;
  } 
